@@ -79,8 +79,8 @@ pCPart::pCPart()
     end = svn::Revision::UNDEFINED;
     toStdout.open(IO_WriteOnly, stdout);
     toStderr.open(IO_WriteOnly, stderr);
-    Stdout.setDevice(TQT_TQIODEVICE(&toStdout));
-    Stderr.setDevice(TQT_TQIODEVICE(&toStderr));
+    Stdout.setDevice(&toStdout);
+    Stderr.setDevice(&toStderr);
     disp = new DummyDisplay();
     m_SvnWrapper = new SvnActions(disp,0,true);
 }
@@ -99,8 +99,8 @@ CommandExec::CommandExec(TQObject*parent, const char *name,TDECmdLineArgs *args)
     SshAgent ag;
     ag.querySshAgent();
 
-    connect(m_pCPart->m_SvnWrapper,TQT_SIGNAL(clientException(const TQString&)),this,TQT_SLOT(clientException(const TQString&)));
-    connect(m_pCPart->m_SvnWrapper,TQT_SIGNAL(sendNotify(const TQString&)),this,TQT_SLOT(slotNotifyMessage(const TQString&)));
+    connect(m_pCPart->m_SvnWrapper,TQ_SIGNAL(clientException(const TQString&)),this,TQ_SLOT(clientException(const TQString&)));
+    connect(m_pCPart->m_SvnWrapper,TQ_SIGNAL(sendNotify(const TQString&)),this,TQ_SLOT(slotNotifyMessage(const TQString&)));
     m_pCPart->m_SvnWrapper->reInitClient();
 }
 
@@ -130,86 +130,86 @@ int CommandExec::exec()
     }
     TQString slotCmd;
     if (!TQString::compare(m_pCPart->cmd,"log")) {
-        slotCmd=TQT_SLOT(slotCmd_log());
+        slotCmd=TQ_SLOT(slotCmd_log());
     } else if (!TQString::compare(m_pCPart->cmd,"cat")) {
-        slotCmd=TQT_SLOT(slotCmd_cat());
+        slotCmd=TQ_SLOT(slotCmd_cat());
         m_pCPart->single_revision=true;
     } else if (!TQString::compare(m_pCPart->cmd,"get")) {
-        slotCmd=TQT_SLOT(slotCmd_get());
+        slotCmd=TQ_SLOT(slotCmd_get());
         m_pCPart->single_revision=true;
     } else if (!TQString::compare(m_pCPart->cmd,"help")) {
-        slotCmd=TQT_SLOT(slotCmd_help());
+        slotCmd=TQ_SLOT(slotCmd_help());
     } else if (!TQString::compare(m_pCPart->cmd,"blame")||
                !TQString::compare(m_pCPart->cmd,"annotate")) {
-        slotCmd=TQT_SLOT(slotCmd_blame());
+        slotCmd=TQ_SLOT(slotCmd_blame());
     } else if (!TQString::compare(m_pCPart->cmd,"update")) {
-        slotCmd=TQT_SLOT(slotCmd_update());
+        slotCmd=TQ_SLOT(slotCmd_update());
         m_pCPart->single_revision=true;
     } else if (!TQString::compare(m_pCPart->cmd,"diff")) {
         m_pCPart->start = svn::Revision::WORKING;
-        slotCmd=TQT_SLOT(slotCmd_diff());
+        slotCmd=TQ_SLOT(slotCmd_diff());
     } else if (!TQString::compare(m_pCPart->cmd,"info")) {
-        slotCmd=TQT_SLOT(slotCmd_info());
+        slotCmd=TQ_SLOT(slotCmd_info());
         m_pCPart->single_revision=true;
     } else if (!TQString::compare(m_pCPart->cmd,"commit")||
                !TQString::compare(m_pCPart->cmd,"ci")) {
-        slotCmd=TQT_SLOT(slotCmd_commit());
+        slotCmd=TQ_SLOT(slotCmd_commit());
     } else if (!TQString::compare(m_pCPart->cmd,"list")||
                !TQString::compare(m_pCPart->cmd,"ls")) {
-        slotCmd=TQT_SLOT(slotCmd_list());
+        slotCmd=TQ_SLOT(slotCmd_list());
     } else if (!TQString::compare(m_pCPart->cmd,"copy")||
                !TQString::compare(m_pCPart->cmd,"cp")) {
-        slotCmd=TQT_SLOT(slotCmd_copy());
+        slotCmd=TQ_SLOT(slotCmd_copy());
         dont_check_second = true;
     } else if (!TQString::compare(m_pCPart->cmd,"move")||
                !TQString::compare(m_pCPart->cmd,"rename")||
                !TQString::compare(m_pCPart->cmd,"mv")) {
-        slotCmd=TQT_SLOT(slotCmd_move());
+        slotCmd=TQ_SLOT(slotCmd_move());
         dont_check_second = true;
     } else if (!TQString::compare(m_pCPart->cmd,"checkout")||
                !TQString::compare(m_pCPart->cmd,"co")) {
-        slotCmd=TQT_SLOT(slotCmd_checkout());
+        slotCmd=TQ_SLOT(slotCmd_checkout());
         dont_check_second = true;
     } else if (!TQString::compare(m_pCPart->cmd,"checkoutto")||
                !TQString::compare(m_pCPart->cmd,"coto")) {
-        slotCmd=TQT_SLOT(slotCmd_checkoutto());
+        slotCmd=TQ_SLOT(slotCmd_checkoutto());
         dont_check_second = true;
     } else if (!TQString::compare(m_pCPart->cmd,"export")) {
-        slotCmd=TQT_SLOT(slotCmd_export());
+        slotCmd=TQ_SLOT(slotCmd_export());
         dont_check_second = true;
     } else if (!TQString::compare(m_pCPart->cmd,"exportto")) {
-        slotCmd=TQT_SLOT(slotCmd_exportto());
+        slotCmd=TQ_SLOT(slotCmd_exportto());
         dont_check_second = true;
     } else if (!TQString::compare(m_pCPart->cmd,"delete")||
                !TQString::compare(m_pCPart->cmd,"del")||
                !TQString::compare(m_pCPart->cmd,"rm")||
                !TQString::compare(m_pCPart->cmd,"remove")) {
-        slotCmd=TQT_SLOT(slotCmd_delete());
+        slotCmd=TQ_SLOT(slotCmd_delete());
     } else if (!TQString::compare(m_pCPart->cmd,"add")) {
-        slotCmd=TQT_SLOT(slotCmd_add());
+        slotCmd=TQ_SLOT(slotCmd_add());
         dont_check_all = true;
         path_only=true;
     } else if (!TQString::compare(m_pCPart->cmd,"undo")||
                !TQString::compare(m_pCPart->cmd,"revert")) {
-        slotCmd=TQT_SLOT(slotCmd_revert());
+        slotCmd=TQ_SLOT(slotCmd_revert());
     } else if (!TQString::compare(m_pCPart->cmd,"checknew")||
                !TQString::compare(m_pCPart->cmd,"addnew")) {
-        slotCmd=TQT_SLOT(slotCmd_addnew());
+        slotCmd=TQ_SLOT(slotCmd_addnew());
     } else if (!TQString::compare(m_pCPart->cmd,"switch")) {
-        slotCmd=TQT_SLOT(slotCmd_switch());
+        slotCmd=TQ_SLOT(slotCmd_switch());
     } else if (!TQString::compare(m_pCPart->cmd,"tree")) {
-        slotCmd=TQT_SLOT(slotCmd_tree());
+        slotCmd=TQ_SLOT(slotCmd_tree());
     } else if (!TQString::compare(m_pCPart->cmd,"lock")) {
-        slotCmd=TQT_SLOT(slotCmd_lock());
+        slotCmd=TQ_SLOT(slotCmd_lock());
         no_revision = true;
         check_force=true;
     } else if (!TQString::compare(m_pCPart->cmd,"unlock")) {
-        slotCmd=TQT_SLOT(slotCmd_unlock());
+        slotCmd=TQ_SLOT(slotCmd_unlock());
         no_revision=true;
         check_force=true;
     }
 
-    bool found = connect(this,TQT_SIGNAL(executeMe()),this,slotCmd.ascii());
+    bool found = connect(this,TQ_SIGNAL(executeMe()),this,slotCmd.ascii());
     if (!found) {
         slotCmd=i18n("Command \"%1\" not implemented or known").arg(m_pCPart->cmd);
         KMessageBox::sorry(0,slotCmd,i18n("SVN Error"));
@@ -314,7 +314,7 @@ int CommandExec::exec()
     if (Kdesvnsettings::self()->cmdline_show_logwindow() &&
         m_lastMessagesLines >= Kdesvnsettings::self()->cmdline_log_minline()) {
         KDialogBase dlg (
-            TQT_TQWIDGET(TDEApplication::activeModalWidget()),
+            TDEApplication::activeModalWidget(),
             "execution_log",
             true,
             i18n("Execution log"),
