@@ -85,12 +85,12 @@ PropertiesDlg::PropertiesDlg(SvnItem*which, svn::Client*aClient, const svn::Revi
     clearWState( WState_Polished );
 
     // signals and slots connections
-    connect( m_AddButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotAdd()));
-    connect( m_ModifyButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotModify()));
-    connect( m_DeleteButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotDelete()));
-    connect(this,TQT_SIGNAL(helpClicked()),TQT_SLOT(slotHelp()));
-    connect(m_PropertiesListview,TQT_SIGNAL(selectionChanged(TQListViewItem*)),this,TQT_SLOT(slotSelectionChanged(TQListViewItem*)));
-//    connect(m_PropertiesListview,TQT_SIGNAL(executed(TQListViewItem*)),this,TQT_SLOT(slotSelectionExecuted(TQListViewItem*)));
+    connect( m_AddButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotAdd()));
+    connect( m_ModifyButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotModify()));
+    connect( m_DeleteButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotDelete()));
+    connect(this,TQ_SIGNAL(helpClicked()),TQ_SLOT(slotHelp()));
+    connect(m_PropertiesListview,TQ_SIGNAL(selectionChanged(TQListViewItem*)),this,TQ_SLOT(slotSelectionChanged(TQListViewItem*)));
+//    connect(m_PropertiesListview,TQ_SIGNAL(executed(TQListViewItem*)),this,TQ_SLOT(slotSelectionExecuted(TQListViewItem*)));
 
     if (!m_Client) {
         m_PropertiesListview->setEnabled(false);
